@@ -1,3 +1,4 @@
+use colored::*;
 use structopt::StructOpt;
 
 #[derive(StructOpt)]
@@ -15,9 +16,14 @@ fn main() {
     let options = Options::from_args();
     let message = options.message;
 
+    if message.to_lowercase() == "woof" {
+        eprintln!("A cow shouldn't bark like a dog.");
+        return;
+    }
+
     let eye = if options.dead { "x" } else { "o" };
 
-    println!("{}", message);
+    println!("{}", message.bright_yellow().underline().on_purple());
     println!("   \\   ^__^");
     println!("     \\  ({}{})\\______", eye, eye);
     println!("        (__)\\      )\\/\\");
